__fpurge

Function __fpurge 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn __fpurge(stream: *mut FILE)
See https://www.man7.org/linux/man-pages/man3/fpurge.3.html.

Non-POSIX. From Solaris.

Clear the buffers of a stream Ensure the file is unlocked before calling this function, as it will attempt to lock the file itself.