fclose

Function fclose 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn fclose(stream: *mut FILE) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/fclose.html.

Close a file This function does not guarentee that the file buffer will be flushed or that the file descriptor will be closed, so if it is important that the file be written to, use fflush() prior to using this function.