#[unsafe(no_mangle)]pub unsafe extern "C" fn ftell(stream: *mut FILE) -> c_longExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/ftell.html.
Get the current position of the cursor in the file
#[unsafe(no_mangle)]pub unsafe extern "C" fn ftell(stream: *mut FILE) -> c_longSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/ftell.html.
Get the current position of the cursor in the file