#[unsafe(no_mangle)]pub unsafe extern "C" fn getc_unlocked(stream: *mut FILE) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/getc_unlocked.html.
Get a char from a stream without locking the stream
#[unsafe(no_mangle)]pub unsafe extern "C" fn getc_unlocked(stream: *mut FILE) -> c_intSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/getc_unlocked.html.
Get a char from a stream without locking the stream