#[unsafe(no_mangle)]pub unsafe extern "C" fn putchar_unlocked(c: c_int) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/getc_unlocked.html.
Put a character c into stdout without locking stdout
#[unsafe(no_mangle)]pub unsafe extern "C" fn putchar_unlocked(c: c_int) -> c_intSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/getc_unlocked.html.
Put a character c into stdout without locking stdout