#[unsafe(no_mangle)]pub unsafe extern "C" fn fflush(stream: *mut FILE) -> c_intExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/fflush.html.
Flush output to stream, or sync read position Ensure the file is unlocked before calling this function, as it will attempt to lock the file itself.